<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueue script and styles */
/*-----------------------------------------------------------------------------------*/

function designer_services_enqueue_google_fonts() {

	require_once get_theme_file_path( 'core/includes/wptt-webfont-loader.php' );

	wp_enqueue_style( 'google-fonts-poppins', 'https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap' );
}
add_action( 'wp_enqueue_scripts', 'designer_services_enqueue_google_fonts' );

if (!function_exists('designer_services_enqueue_scripts')) {

	function designer_services_enqueue_scripts() {

		wp_enqueue_style(
			'bootstrap-css',
			get_template_directory_uri() . '/css/bootstrap.css',
			array(),'4.5.0'
		);

		wp_enqueue_style(
			'fontawesome-css',
			get_template_directory_uri() . '/css/fontawesome-all.css',
			array(),'4.5.0'
		);

		wp_enqueue_style(
			'slick-css',
			get_template_directory_uri() . '/css/slick.css',
			array(),'2.3.4'
		);

		wp_enqueue_style('designer-services-style', get_stylesheet_uri(), array() );

		wp_style_add_data('designer-services-style', 'rtl', 'replace');

		wp_enqueue_style(
			'designer-services-media-css',
			get_template_directory_uri() . '/css/media.css',
			array(),'2.3.4'
		);

		wp_enqueue_style(
			'designer-services-woocommerce-css',
			get_template_directory_uri() . '/css/woocommerce.css',
			array(),'2.3.4'
		);

		wp_enqueue_script(
			'designer-services-navigation',
			get_template_directory_uri() . '/js/navigation.js',
			FALSE,
			'1.0',
			TRUE
		);

		wp_enqueue_script(
			'slick-min-js',
			get_template_directory_uri() . '/js/slick.min.js',
			array('jquery'),
			'2.3.4',
			TRUE
		);

		wp_enqueue_script(
			'designer-services-script',
			get_template_directory_uri() . '/js/script.js',
			array('jquery'),
			'1.0',
			TRUE
		);

		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );

		$designer_services_css = '';

		if ( get_header_image() ) :

			$designer_services_css .=  '
				#site-navigation{
					background-image: url('.esc_url(get_header_image()).');
					-webkit-background-size: cover !important;
					-moz-background-size: cover !important;
					-o-background-size: cover !important;
					background-size: cover !important;
				}';

		endif;

		wp_add_inline_style( 'designer-services-style', $designer_services_css );

		// Theme Customize CSS.
		require get_template_directory(). '/core/includes/inline.php';
		wp_add_inline_style( 'designer-services-style',$designer_services_custom_css );

	}

	add_action( 'wp_enqueue_scripts', 'designer_services_enqueue_scripts' );

}

/*-----------------------------------------------------------------------------------*/
/* Setup theme */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('designer_services_after_setup_theme')) {

	function designer_services_after_setup_theme() {

		if ( ! isset( $designer_services_content_width ) ) $designer_services_content_width = 900;

		register_nav_menus( array(
			'main-menu' => esc_html__( 'Main menu', 'designer-services' ),
		));

		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'woocommerce' );
		add_theme_support( 'align-wide' );
		add_theme_support('title-tag');
		add_theme_support('automatic-feed-links');
		add_theme_support( 'wp-block-styles' );
		add_theme_support('post-thumbnails');
		add_theme_support( 'custom-background', array(
		  'default-color' => 'f3f3f3'
		));

		add_theme_support( 'custom-logo', array(
			'height'      => 70,
			'width'       => 70,
		) );

		add_theme_support( 'custom-header', array(
			'header-text' => false,
			'width' => 1920,
			'height' => 100
		));

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_editor_style( array( '/css/editor-style.css' ) );
	}

	add_action( 'after_setup_theme', 'designer_services_after_setup_theme', 999 );

}

require get_template_directory() .'/core/includes/main.php';
require get_template_directory() .'/core/includes/tgm.php';
require get_template_directory() . '/core/includes/customizer.php';
load_template( trailingslashit( get_template_directory() ) . '/core/includes/class-upgrade-pro.php' );

/*-----------------------------------------------------------------------------------*/
/* Enqueue theme logo style */
/*-----------------------------------------------------------------------------------*/
function designer_services_logo_resizer() {

    $designer_services_theme_logo_size_css = '';
    $designer_services_logo_resizer = get_theme_mod('designer_services_logo_resizer');

	$designer_services_theme_logo_size_css = '
		.custom-logo{
			height: '.esc_attr($designer_services_logo_resizer).'px !important;
			width: '.esc_attr($designer_services_logo_resizer).'px !important;
		}
	';
    wp_add_inline_style( 'designer-services-style',$designer_services_theme_logo_size_css );

}
add_action( 'wp_enqueue_scripts', 'designer_services_logo_resizer' );

/*-----------------------------------------------------------------------------------*/
/* Enqueue Global color style */
/*-----------------------------------------------------------------------------------*/
function designer_services_global_color() {

    $designer_services_theme_color_css = '';
    $designer_services_global_color = get_theme_mod('designer_services_global_color');
    $designer_services_global_color_2 = get_theme_mod('designer_services_global_color_2');
    $designer_services_copyright_bg = get_theme_mod('designer_services_copyright_bg');

	$designer_services_theme_color_css = '
	#main-menu ul.children li a:hover,#main-menu ul.sub-menu li a:hover,.post-button a,.project .tablinks:hover,.project .tablinks.active,.post-button a,.project .tablinks:hover,.project .tablinks.active,.scroll-up a,.pagination .nav-links a:hover,.pagination .nav-links a:focus,.pagination .nav-links span.current,.designer-services-pagination span.current,.designer-services-pagination span.current:hover,.designer-services-pagination span.current:focus,.designer-services-pagination a span:hover,.designer-services-pagination a span:focus,.comment-respond input#submit,.sidebar-area .tagcloud a,.searchform input[type=submit],.searchform input[type=submit]:hover ,.searchform input[type=submit]:focus,#slider .button:hover,.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce a.added_to_cart,.comment-reply a,.sidebar-area h4.title,button.close-menu,.menu-toggle, .dropdown-toggle,nav.woocommerce-MyAccount-navigation ul li	{
			background: '.esc_attr($designer_services_global_color).';
		}
		a:hover,a:focus,.post-single a, .page-single a,.sidebar-area .textwidget a,.comment-content a,.woocommerce-product-details__short-description a,#tab-description a,.extra-home-content a,.topheader span i,.header-search button.search-button i,#main-menu a:hover,#main-menu ul li a:hover,#main-menu li:hover > a,#main-menu a:focus,#main-menu ul li a:focus,#main-menu li.focus > a,#main-menu li:focus > a,#main-menu ul li.current-menu-item > a,#main-menu ul li.current_page_item > a,#main-menu ul li.current-menu-parent > a,#main-menu ul li.current_page_ancestor > a,#main-menu ul li.current-menu-ancestor > a,.post-meta i,.projects_content_box span,.projects_content_box span,.woocommerce ul.products li.product .price, .woocommerce div.product p.price, .woocommerce div.product span.price{
			color: '.esc_attr($designer_services_global_color).';
		}
		#slider .slick-dots LI.slick-active{
			border-color: '.esc_attr($designer_services_global_color).';
		}
		@media screen and (min-width: 320px) and (max-width: 767px)
		.page-template-frontpage #site-navigation {
				background: '.esc_attr($designer_services_global_color_2).' !important;
		}
		.copyright {
			background: '.esc_attr($designer_services_copyright_bg).';
		}
	';
    wp_add_inline_style( 'designer-services-style',$designer_services_theme_color_css );
    wp_add_inline_style( 'designer-services-woocommerce-css',$designer_services_theme_color_css );
}
add_action( 'wp_enqueue_scripts', 'designer_services_global_color' );

/*-----------------------------------------------------------------------------------*/
/* Get post comments */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('designer_services_comment')) :
    /**
     * Template for comments and pingbacks.
     *
     * Used as a callback by wp_list_comments() for displaying the comments.
     */
    function designer_services_comment($comment, $args, $depth){

        if ('pingback' == $comment->comment_type || 'trackback' == $comment->comment_type) : ?>

            <li id="comment-<?php comment_ID(); ?>" <?php comment_class('media'); ?>>
            <div class="comment-body">
                <?php esc_html_e('Pingback:', 'designer-services');
                comment_author_link(); ?><?php edit_comment_link(__('Edit', 'designer-services'), '<span class="edit-link">', '</span>'); ?>
            </div>

        <?php else : ?>

        <li id="comment-<?php comment_ID(); ?>" <?php comment_class(empty($args['has_children']) ? '' : 'parent'); ?>>
            <article id="div-comment-<?php comment_ID(); ?>" class="comment-body media mb-4">
                <a class="pull-left" href="#">
                    <?php if (0 != $args['avatar_size']) echo get_avatar($comment, $args['avatar_size']); ?>
                </a>
                <div class="media-body">
                    <div class="media-body-wrap card">
                        <div class="card-header">
                            <h5 class="mt-0"><?php /* translators: %s: author */ printf('<cite class="fn">%s</cite>', get_comment_author_link() ); ?></h5>
                            <div class="comment-meta">
                                <a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>">
                                    <time datetime="<?php comment_time('c'); ?>">
                                        <?php /* translators: %s: Date */ printf( esc_attr('%1$s at %2$s', '1: date, 2: time', 'designer-services'), esc_attr( get_comment_date() ), esc_attr( get_comment_time() ) ); ?>
                                    </time>
                                </a>
                                <?php edit_comment_link( __( 'Edit', 'designer-services' ), '<span class="edit-link">', '</span>' ); ?>
                            </div>
                        </div>

                        <?php if ('0' == $comment->comment_approved) : ?>
                            <p class="comment-awaiting-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'designer-services'); ?></p>
                        <?php endif; ?>

                        <div class="comment-content card-block">
                            <?php comment_text(); ?>
                        </div>

                        <?php comment_reply_link(
                            array_merge(
                                $args, array(
                                    'add_below' => 'div-comment',
                                    'depth' => $depth,
                                    'max_depth' => $args['max_depth'],
                                    'before' => '<footer class="reply comment-reply card-footer">',
                                    'after' => '</footer><!-- .reply -->'
                                )
                            )
                        ); ?>
                    </div>
                </div>
            </article>

            <?php
        endif;
    }
endif; // ends check for designer_services_comment()

if (!function_exists('designer_services_widgets_init')) {

	function designer_services_widgets_init() {

		register_sidebar(array(

			'name' => esc_html__('Sidebar','designer-services'),
			'id'   => 'designer-services-sidebar',
			'description'   => esc_html__('This sidebar will be shown next to the content.', 'designer-services'),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title">',
			'after_title'   => '</h4>'

		));

		register_sidebar(array(

			'name' => esc_html__('Footer sidebar','designer-services'),
			'id'   => 'designer-services-footer-sidebar',
			'description'   => esc_html__('This sidebar will be shown next at the bottom of your content.', 'designer-services'),
			'before_widget' => '<div id="%1$s" class="col-lg-3 col-md-3 %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title">',
			'after_title'   => '</h4>'

		));

	}

	add_action( 'widgets_init', 'designer_services_widgets_init' );

}

function designer_services_get_categories_select() {
	$designer_services_teh_cats = get_categories();
	$results = array();
	$designer_services_count = count($designer_services_teh_cats);
	for ($i=0; $i < $designer_services_count; $i++) {
	if (isset($designer_services_teh_cats[$i]))
  		$results[$designer_services_teh_cats[$i]->slug] = $designer_services_teh_cats[$i]->name;
	else
  		$designer_services_count++;
	}
	return $results;
}

/**
 * Change number or products per row to 3
 */
add_filter('loop_shop_columns', 'designer_services_loop_columns', 999);
if (!function_exists('designer_services_loop_columns')) {
	function designer_services_loop_columns() {
		return 3; // 3 products per row
	}
}

function designer_services_sanitize_phone_number( $phone ) {
	return preg_replace( '/[^\d+]/', '', $phone );
}

//redirect
Function designer_services_notice(){
    global $pagenow;
    if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
   		wp_safe_redirect( admin_url("themes.php?page=designer-services-guide-page") );
   	}
}
add_action('after_setup_theme', 'designer_services_notice');

?>
